#ifndef TAILWIDGET_H
#define TAILWIDGET_H

#include <QWidget>
#include <QTimer>
#include <QFileSystemWatcher>
#include <QFile>
#include <QBoxLayout>
#include <QTextStream>
#include <QScrollBar>
#include <QtUiPlugin/QDesignerExportWidget>

#include "textwidget.h"

class QDESIGNER_WIDGET_EXPORT TailWidget : public QWidget
{
   Q_OBJECT

public:
    TailWidget(QWidget *parent = 0);
    virtual ~TailWidget();

    bool load(QString f);
    void setFileName( QString fileName );
    void clearContents();
    void pause(bool);

    void setgBackColor(const QColor cv);
    inline QColor getgBackColor() const { return this->m_bgColor; }

    void setTextColor(const QColor cv);
    inline QColor getTextColor() const { return this->m_textColor; }

    void setTextFont(const QFont fv);
    inline QFont getTextFont() const { return this->f; }

    void setWrapText( const bool wrapText );
    inline bool getWrapText() const { return this->m_wrapText; }

protected:
   void closeEvent(QCloseEvent *);

signals:
    void windowClosed(QString);

private slots:
    void fileChanged(QString);
    void windowClicked();
    bool reRead();


private:
    void setChanged(){ fileHasChanged = true; }
    bool setFile(qint64 pos);
    bool checkFile(QString fileName);

    bool fileHasChanged, paused, initial;
    qint64 lastPos;
    QString fileName, filter;
    QFile file;
    QFileSystemWatcher * watcher;
    TextWidget * textView;
    QPalette p;
    QTimer *timer;

    QColor m_bgColor;
    QColor m_textColor;
    bool m_wrapText;
    QFont  f;

    void loadFile( QString fileName );
    QString getFileName();
};

#endif // TAILWIDGET_H
